package com.dayou.aspect;

import com.dayou.annotation.DataPermission;
import com.dayou.common.SimpleListModel;
import com.dayou.service.IUserService;
import com.dayou.utils.LoginContext;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.lang.reflect.Field;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * 类说明：
 *
 * @author: wucl
 * @since: 2023/2/13
 * created with IntelliJ IDEA.
 */

@Slf4j
@Component
@Aspect
public class DataPermissionAop {

    @Autowired
    private IUserService userService;

    @Pointcut("@annotation(com.dayou.annotation.DataPermission)")
    public void dataPermissionPointcut(){

    }

    @Around("dataPermissionPointcut() && @annotation(dataPermission)")
    public Object  beforeHandle(ProceedingJoinPoint joinPoint, DataPermission dataPermission) throws Throwable {
        Set<Long> users = new HashSet<>();
        Long userId = LoginContext.getUserId();
        if (dataPermission.isJunior()){
            //根据当前登录人获取下属员工id
            users = userService.getJuniorUserId(userId);
        }
        users.add(userId);
        Object arg = joinPoint.getArgs()[0];
        Field userIds = arg.getClass().getDeclaredField("userIds");
        userIds.setAccessible(Boolean.TRUE);
        userIds.set(arg,users);
        return joinPoint.proceed();

    }
}
